@@ -39,7 +39,8 @@ class WriterFilter:
         "Simple_sign_epistasis": 19,
         "Reciprocal_sign_epistasis": 20,
         "Ratio_of_overlapping_genotype_sets": 21,
-        "Overlapping_genotype_sets": 22
+        "Overlapping_genotype_sets": 22,
+        "Epistasis_squares": 23
     }
 
     # Genotype level attribute to order map
